/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_psAEyiSR);
  numBytes += sLine_init(&sLine_SY2ByVhZ);
  numBytes += sTabhead_init(&sTabhead_C8LlioRL, &hTable_6Y4X3WlS);
  numBytes += sTabread_init(&sTabread_P5vxBnxb, &hTable_6Y4X3WlS, false);
  numBytes += sTabread_init(&sTabread_NqIexGlN, &hTable_6Y4X3WlS, false);
  numBytes += sLine_init(&sLine_mX4XOBoG);
  numBytes += sLine_init(&sLine_PqLQTKF0);
  numBytes += sLine_init(&sLine_p4Mwwn1a);
  numBytes += sTabhead_init(&sTabhead_lc2pWtRZ, &hTable_bLJS4gZp);
  numBytes += sTabread_init(&sTabread_QQr15uAR, &hTable_bLJS4gZp, false);
  numBytes += sTabread_init(&sTabread_1b2z7fxW, &hTable_bLJS4gZp, false);
  numBytes += sLine_init(&sLine_Vrj2IzPC);
  numBytes += sTabwrite_init(&sTabwrite_rjWL8mkl, &hTable_6Y4X3WlS);
  numBytes += sTabwrite_init(&sTabwrite_TZalSJHo, &hTable_bLJS4gZp);
  numBytes += sRPole_init(&sRPole_5iTIs5aN);
  numBytes += sRPole_init(&sRPole_3ySRZJZP);
  numBytes += sRPole_init(&sRPole_EchHXCMh);
  numBytes += sDel1_init(&sDel1_sGQ1bkj5);
  numBytes += sLine_init(&sLine_wudy6ehS);
  numBytes += sLine_init(&sLine_bnczco2C);
  numBytes += sRPole_init(&sRPole_awfIb1zX);
  numBytes += sRPole_init(&sRPole_OMZ0gO8p);
  numBytes += sRPole_init(&sRPole_5u2Uo14U);
  numBytes += sDel1_init(&sDel1_SQFsElvz);
  numBytes += sLine_init(&sLine_Dn9wgpn5);
  numBytes += sLine_init(&sLine_PzBLxsC6);
  numBytes += sLine_init(&sLine_71hDwW7i);
  numBytes += sLine_init(&sLine_CLErjpPs);
  numBytes += cVar_init_f(&cVar_ifWQ9olc, 0.0f);
  numBytes += cVar_init_f(&cVar_7dNWO8EP, 0.0f);
  numBytes += cVar_init_f(&cVar_OZomoQR4, 0.0f);
  numBytes += cVar_init_f(&cVar_gnfJXszD, 0.0f);
  numBytes += cSlice_init(&cSlice_zI3v7Ej8, 1, -1);
  numBytes += cVar_init_f(&cVar_yUE2BQS1, 0.5f);
  numBytes += cSlice_init(&cSlice_WPvaqlCR, 1, -1);
  numBytes += cVar_init_f(&cVar_2mqeikrF, 0.2f);
  numBytes += cSlice_init(&cSlice_ImCUJfE4, 1, -1);
  numBytes += cVar_init_f(&cVar_A4FpJGZX, 500.0f);
  numBytes += cSlice_init(&cSlice_FJ4tca18, 1, -1);
  numBytes += cVar_init_f(&cVar_Ssf5KvsB, 0.25f);
  numBytes += cDelay_init(this, &cDelay_3JDWWHXH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_mYumhn8v, 0.0f);
  numBytes += hTable_init(&hTable_6Y4X3WlS, 256);
  numBytes += cDelay_init(this, &cDelay_AQQqtAoP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_unWvSH5z, 0.0f);
  numBytes += hTable_init(&hTable_bLJS4gZp, 256);
  numBytes += cVar_init_f(&cVar_f5vNNmAN, 8000.0f);
  numBytes += cBinop_init(&cBinop_Dww7JcDK, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tBc71MxI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7uakEZQQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_xlr09doe, 8000.0f);
  numBytes += cBinop_init(&cBinop_ZsK1QIQn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_0rPcyns3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NMBHp1Ay, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XQgOHDd9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_MsySs15b, 300.0f);
  numBytes += cBinop_init(&cBinop_sWJ16iTK, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Kl7m588x, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_IrFu2BV1, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_d5QMGbx1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ThCfEp2S, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ev8nsZmV, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_gRfDujDc, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_abEOTDIT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PEl0cM2j, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jXjgYgtO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_eHIi3Mdz, 8000.0f);
  numBytes += cBinop_init(&cBinop_K7gZXQOx, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_kBPg30wm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kC3UN6mQ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_YNDWupEV, 8000.0f);
  numBytes += cBinop_init(&cBinop_6B9sjaqx, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_CgILEHAU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Aj6f2uu2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GJgZ3Jy7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_wgD0ulil, 300.0f);
  numBytes += cBinop_init(&cBinop_sWFdZFAz, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_5FFGs6CN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RFyf6PBp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_upAXo88O, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_I5yZpeK0, 1.0f);
  numBytes += cIf_init(&cIf_9wWGO2dI, false);
  numBytes += cIf_init(&cIf_gvekM5xi, false);
  numBytes += cVar_init_f(&cVar_YrZ4tAZC, 0.0f);
  numBytes += cVar_init_f(&cVar_wvl2CAg6, 0.0f);
  numBytes += cVar_init_f(&cVar_yk3Q6Tt6, 60000.0f);
  numBytes += cVar_init_f(&cVar_hOaSN32j, 500.0f);
  numBytes += cSlice_init(&cSlice_4poTlJ59, 1, -1);
  numBytes += cSlice_init(&cSlice_n6IUYVV2, 1, -1);
  numBytes += cVar_init_f(&cVar_nn5IH9ff, 0.0f);
  numBytes += cIf_init(&cIf_jf1F7X5r, false);
  numBytes += cBinop_init(&cBinop_s76YUkzC, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_JAJgGrsQ, 120.0f);
  numBytes += cBinop_init(&cBinop_ckewGtO9, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_6fd15RkK, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_6Y4X3WlS);
  hTable_free(&hTable_bLJS4gZp);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_6Y4X3WlS; // del-1011-delayL
    case 0xF057CB49: return &hTable_bLJS4gZp; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mX0J9hDm_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r1ICWVDT_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Wy0cO46O_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xhLcxRyO_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fhpnkoLS_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ccmRaM6d_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3oesDe33_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4bKTdrgj_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZgNOC9Kf_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p6TfFmTj_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_muzsMn5s_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uvfrlPUG_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_ifWQ9olc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eEjsE6uM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_7dNWO8EP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WDN0vWCe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_OZomoQR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4u3fXgBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_gnfJXszD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1Vqio2Pf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_Hnj8qHFV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zI3v7Ej8, 0, m, &cSlice_zI3v7Ej8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_zI3v7Ej8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EpkWNJUD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EpkWNJUD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_yUE2BQS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EpkWNJUD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_EpkWNJUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZgNOC9Kf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_knQbggNV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WPvaqlCR, 0, m, &cSlice_WPvaqlCR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6eUGuIGi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_WPvaqlCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DuhAe9M5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DuhAe9M5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_2mqeikrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DuhAe9M5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_DuhAe9M5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3oesDe33_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_azLd3mrQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ImCUJfE4, 0, m, &cSlice_ImCUJfE4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Hnj8qHFV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_ImCUJfE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ycNxTpse_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ycNxTpse_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_A4FpJGZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ycNxTpse_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_ycNxTpse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p6TfFmTj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_1U5Kwt8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YqjG78PL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YqjG78PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_78coT0Y6_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_jM34Z6ni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6guIdFNI_sendMessage(_c, 0, m);
  cMsg_GIcYNYpe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_nbwj9iXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_13Z1jQ5K_sendMessage(_c, 0, m);
  cMsg_f4fhYsqr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_78coT0Y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Tp3Dhuji_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Tp3Dhuji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2hpWJdgH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kesiMKnH_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_kesiMKnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_peRHsaGw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_2hpWJdgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_dBEpGtas_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dBEpGtas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jmq8gNQK_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_peRHsaGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yd571GCd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yd571GCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1ZfCg0Ek_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jmq8gNQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_jM34Z6ni_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1ZfCg0Ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_nbwj9iXk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PTrVRoVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_QgdI9dut_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QgdI9dut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Ji91ao5W_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Ji91ao5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_IKv9m3kY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_IKv9m3kY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z1WQYvWx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xCt4tES8_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_z1WQYvWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wpWXJASq_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_xCt4tES8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2vV7LQRM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_wpWXJASq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_B4gV7Djw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2vV7LQRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XAWCy5of_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XAWCy5of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_aKfIke8b_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_aKfIke8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RetYYVmm_sendMessage(_c, 0, m);
  cMsg_nQlNUy7Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_B4gV7Djw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5cyaypAS_sendMessage(_c, 0, m);
  cMsg_iHA4jcOL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_6eUGuIGi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FJ4tca18, 0, m, &cSlice_FJ4tca18_sendMessage);
      break;
    }
    default: {
      cSwitchcase_azLd3mrQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_FJ4tca18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M3wYou7u_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M3wYou7u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_Ssf5KvsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M3wYou7u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_M3wYou7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4bKTdrgj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_hxc7ZP9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yqXe7Ik3_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_yqXe7Ik3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_baYrBAp6_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_3JDWWHXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3JDWWHXH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mYumhn8v, 0, m, &cDelay_mYumhn8v_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3JDWWHXH, 0, m, &cDelay_3JDWWHXH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rjWL8mkl, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_mYumhn8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mYumhn8v, m);
  cMsg_d3wWXw9q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_4NhC9bUX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_MuRta2LB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_Gs3DW0Ey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9XRNEqot_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_6Y4X3WlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NcK1OQcQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3JDWWHXH, 2, m, &cDelay_3JDWWHXH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_84D3kKMv_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9XRNEqot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_6Y4X3WlS, 0, m, &hTable_6Y4X3WlS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_baYrBAp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_Gs3DW0Ey_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_d3wWXw9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_6Y4X3WlS, 0, m, &hTable_6Y4X3WlS_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_84D3kKMv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3JDWWHXH, 0, m, &cDelay_3JDWWHXH_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_NcK1OQcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_mYumhn8v, 2, m, &cDelay_mYumhn8v_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_MuRta2LB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rjWL8mkl, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7bgNDMzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jJ8ys1HB_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_jJ8ys1HB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_XOkNDCnd_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_AQQqtAoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AQQqtAoP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_unWvSH5z, 0, m, &cDelay_unWvSH5z_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQQqtAoP, 0, m, &cDelay_AQQqtAoP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TZalSJHo, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_unWvSH5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_unWvSH5z, m);
  cMsg_kd97iut1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_ZNBzjf5j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_HfVDdgjv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_E0LDkeDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zpKyuUoF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_bLJS4gZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wkrGDCeh_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQQqtAoP, 2, m, &cDelay_AQQqtAoP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qi2UCjU8_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_zpKyuUoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_bLJS4gZp, 0, m, &hTable_bLJS4gZp_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XOkNDCnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_E0LDkeDI_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_kd97iut1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_bLJS4gZp, 0, m, &hTable_bLJS4gZp_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Qi2UCjU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AQQqtAoP, 0, m, &cDelay_AQQqtAoP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_wkrGDCeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_unWvSH5z, 2, m, &cDelay_unWvSH5z_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_HfVDdgjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_TZalSJHo, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_f5vNNmAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dww7JcDK, HV_BINOP_MULTIPLY, 0, m, &cBinop_Dww7JcDK_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_vZlx34UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YCuFYauI_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_YCuFYauI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PTz2LMiJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_Dww7JcDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ywd223lA_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_011pNfA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Dww7JcDK, HV_BINOP_MULTIPLY, 1, m, &cBinop_Dww7JcDK_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PTz2LMiJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_011pNfA6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ywd223lA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_exzf3rN5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_exzf3rN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TwXnoscz_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7uakEZQQ, m);
}

void Heavy_WSTD_DLAY::cBinop_TwXnoscz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tBc71MxI, m);
}

void Heavy_WSTD_DLAY::cVar_xlr09doe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZsK1QIQn, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZsK1QIQn_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_MivokDJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_21F8i8ce_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_21F8i8ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LK3BJdQb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ZsK1QIQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_OWie78zk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_GwRFTDJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZsK1QIQn, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZsK1QIQn_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_LK3BJdQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GwRFTDJ5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_OWie78zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_rEdj0hCB_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rEdj0hCB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_asuq8EkV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NMBHp1Ay, m);
}

void Heavy_WSTD_DLAY::cBinop_asuq8EkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0rPcyns3, m);
}

void Heavy_WSTD_DLAY::cBinop_5FtY3y3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_b344YQJ4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_b344YQJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7rJpmfJT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_v950Rkue_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_MsySs15b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_z7Usf6Yk_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_792o1F37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NHoAa2xF_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_NHoAa2xF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sWJ16iTK, HV_BINOP_DIVIDE, 1, m, &cBinop_sWJ16iTK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7rJpmfJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_S5IZqM61_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_S5IZqM61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Kl7m588x, m);
}

void Heavy_WSTD_DLAY::cMsg_GnQnvfBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nHcPxzpd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nHcPxzpd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_5FtY3y3v_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_v950Rkue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XQgOHDd9, m);
}

void Heavy_WSTD_DLAY::cBinop_z7Usf6Yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_wCAjO3dN_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_wCAjO3dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sWJ16iTK, HV_BINOP_DIVIDE, 0, m, &cBinop_sWJ16iTK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sWJ16iTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GnQnvfBh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_IerXNTXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cw1QqdQQ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_cw1QqdQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_r33keX9y_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_IrFu2BV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6efK2HR3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_42DounHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_5BE8LNGl_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_d5QMGbx1, m);
}

void Heavy_WSTD_DLAY::cBinop_r33keX9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ThCfEp2S, m);
}

void Heavy_WSTD_DLAY::cMsg_6efK2HR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_42DounHf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5BE8LNGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ev8nsZmV, m);
}

void Heavy_WSTD_DLAY::cMsg_0kuVbo01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Q4myVKmw_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Q4myVKmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eHWL9HgR_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_gRfDujDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_plssL6Oa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_2f3KxNna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_co8Snsms_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_abEOTDIT, m);
}

void Heavy_WSTD_DLAY::cBinop_eHWL9HgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PEl0cM2j, m);
}

void Heavy_WSTD_DLAY::cMsg_plssL6Oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2f3KxNna_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_co8Snsms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_jXjgYgtO, m);
}

void Heavy_WSTD_DLAY::cVar_eHIi3Mdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7gZXQOx, HV_BINOP_MULTIPLY, 0, m, &cBinop_K7gZXQOx_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XS7FElGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZF3IgOJ3_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ZF3IgOJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6aGDNHDY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_K7gZXQOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_vu46EY4M_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_zWjk2UjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7gZXQOx, HV_BINOP_MULTIPLY, 1, m, &cBinop_K7gZXQOx_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_6aGDNHDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zWjk2UjW_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vu46EY4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_lGu8RheP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_lGu8RheP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_51ddlN1K_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kC3UN6mQ, m);
}

void Heavy_WSTD_DLAY::cBinop_51ddlN1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_kBPg30wm, m);
}

void Heavy_WSTD_DLAY::cVar_YNDWupEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6B9sjaqx, HV_BINOP_MULTIPLY, 0, m, &cBinop_6B9sjaqx_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5imm2WWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5w899kOJ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_5w899kOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gGlpLr3j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_6B9sjaqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QcKitsxz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MBVGWuBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6B9sjaqx, HV_BINOP_MULTIPLY, 1, m, &cBinop_6B9sjaqx_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gGlpLr3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MBVGWuBn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QcKitsxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_5gisrWKS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_5gisrWKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VgKkZAay_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Aj6f2uu2, m);
}

void Heavy_WSTD_DLAY::cBinop_VgKkZAay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CgILEHAU, m);
}

void Heavy_WSTD_DLAY::cBinop_bLR4ItGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_ZLNGWry1_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZLNGWry1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Jk8Hhppn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WJJokqBK_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_wgD0ulil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_bHHy1THq_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_eZVg5U2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dz40T9vh_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_dz40T9vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sWFdZFAz, HV_BINOP_DIVIDE, 1, m, &cBinop_sWFdZFAz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Jk8Hhppn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RfEVqct9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_RfEVqct9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5FFGs6CN, m);
}

void Heavy_WSTD_DLAY::cMsg_nRPBDwxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FHqBbHIk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_FHqBbHIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_bLR4ItGb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WJJokqBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GJgZ3Jy7, m);
}

void Heavy_WSTD_DLAY::cBinop_bHHy1THq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_vW8QQu6Z_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vW8QQu6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sWFdZFAz, HV_BINOP_DIVIDE, 0, m, &cBinop_sWFdZFAz_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sWFdZFAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nRPBDwxd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_6guIdFNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mX4XOBoG, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_13Z1jQ5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_psAEyiSR, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_f4fhYsqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PqLQTKF0, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_GIcYNYpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Vrj2IzPC, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_iHA4jcOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PzBLxsC6, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_RetYYVmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bnczco2C, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_5cyaypAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CLErjpPs, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_nQlNUy7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_71hDwW7i, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_5wFYQjKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SY2ByVhZ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_HBX8Jlgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p4Mwwn1a, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_wwIlexPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wudy6ehS, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_3udlhUZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dn9wgpn5, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_I5yZpeK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nYsCo5G4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T0PKkI9x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NfnYLDdq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_nYsCo5G4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I5yZpeK0, 1, m, &cVar_I5yZpeK0_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_9wWGO2dI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_7dNWO8EP, 0, m, &cVar_7dNWO8EP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_gvekM5xi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_7dNWO8EP, 0, m, &cVar_7dNWO8EP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_YrZ4tAZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gvekM5xi, 0, m, &cIf_gvekM5xi_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_wvl2CAg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9wWGO2dI, 0, m, &cIf_9wWGO2dI_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_yk3Q6Tt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckewGtO9, HV_BINOP_DIVIDE, 0, m, &cBinop_ckewGtO9_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_hOaSN32j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6fd15RkK, HV_BINOP_MULTIPLY, 1, m, &cBinop_6fd15RkK_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_gImlrHMa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4poTlJ59, 0, m, &cSlice_4poTlJ59_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n6IUYVV2, 0, m, &cSlice_n6IUYVV2_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IacaxXz1_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2hQTFAo4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_4poTlJ59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_nn5IH9ff, 0, m, &cVar_nn5IH9ff_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_nn5IH9ff, 0, m, &cVar_nn5IH9ff_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_n6IUYVV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_s76YUkzC, HV_BINOP_NEQ, 1, m, &cBinop_s76YUkzC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_nn5IH9ff, 1, m, &cVar_nn5IH9ff_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_s76YUkzC, HV_BINOP_NEQ, 1, m, &cBinop_s76YUkzC_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_nn5IH9ff, 1, m, &cVar_nn5IH9ff_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_nn5IH9ff_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_GDLZaHe2_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_jf1F7X5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3GALuFgV_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fJlR7m3y_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_fJlR7m3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nn5IH9ff, 0, m, &cVar_nn5IH9ff_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_3GALuFgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s76YUkzC, HV_BINOP_NEQ, 1, m, &cBinop_s76YUkzC_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_s76YUkzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jf1F7X5r, 1, m, &cIf_jf1F7X5r_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_2hQTFAo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jf1F7X5r, 0, m, &cIf_jf1F7X5r_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_IacaxXz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s76YUkzC, HV_BINOP_NEQ, 0, m, &cBinop_s76YUkzC_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_JAJgGrsQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QhskTTes_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qWp5lXuH_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_Vi8P4x4Z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HRMK26b9_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ALvlse0Z_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_03wsokcw_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XNBgK53p_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1fTaNBVZ_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xa4lZM6f_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Lm3IoON_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LZwgtu5u_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zKMxAiWA_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GxXu7JBY_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vCnhnTbm_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gHw3oslj_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RQuC3MKH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_HRMK26b9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8igfV476_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ALvlse0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oaTy7tu0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_03wsokcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JWpLoa03_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_XNBgK53p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TIoZNzNf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_1fTaNBVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3OUaSYxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Xa4lZM6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8zKHFJJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_5Lm3IoON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EuFIVo7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_LZwgtu5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5zEuDjku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_zKMxAiWA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZIbESW6B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_GxXu7JBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UVvqre6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_vCnhnTbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FZU7rWie_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_gHw3oslj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FbP6lcEf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_RQuC3MKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lQtfQPpX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ckewGtO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6fd15RkK, HV_BINOP_MULTIPLY, 0, m, &cBinop_6fd15RkK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6fd15RkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gImlrHMa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_qWp5lXuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yk3Q6Tt6, 0, m, &cVar_yk3Q6Tt6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hOaSN32j, 0, m, &cVar_hOaSN32j_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_QhskTTes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckewGtO9, HV_BINOP_DIVIDE, 1, m, &cBinop_ckewGtO9_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_svgkNUzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yk3Q6Tt6, 0, m, &cVar_yk3Q6Tt6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_1YQPu7Gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hOaSN32j, 0, m, &cVar_hOaSN32j_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_8igfV476_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_oaTy7tu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JWpLoa03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_TIoZNzNf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3OUaSYxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_8zKHFJJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_EuFIVo7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_5zEuDjku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ZIbESW6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_UVvqre6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_FZU7rWie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_FbP6lcEf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lQtfQPpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YQPu7Gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_svgkNUzw_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_1Vqio2Pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_knQbggNV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_eEjsE6uM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_knQbggNV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_FizgDTsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gnfJXszD, 0, m, &cVar_gnfJXszD_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_TRDuF8hZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ifWQ9olc, 0, m, &cVar_ifWQ9olc_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_95zhQVZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OZomoQR4, 0, m, &cVar_OZomoQR4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_WDN0vWCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_knQbggNV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_4u3fXgBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_knQbggNV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_GDLZaHe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wvl2CAg6, 0, m, &cVar_wvl2CAg6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NfnYLDdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c5dzVnWv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pX71oNLU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_T0PKkI9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BAB00Yg6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wnZl5LZn_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_wnZl5LZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YrZ4tAZC, 0, m, &cVar_YrZ4tAZC_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_BAB00Yg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gvekM5xi, 1, m, &cIf_gvekM5xi_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_c5dzVnWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9wWGO2dI, 1, m, &cIf_9wWGO2dI_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_pX71oNLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wvl2CAg6, 0, m, &cVar_wvl2CAg6_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_Wy0cO46O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_FizgDTsM_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_r1ICWVDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TRDuF8hZ_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_mX0J9hDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_95zhQVZG_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_fhpnkoLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YrZ4tAZC, 0, m, &cVar_YrZ4tAZC_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_p6TfFmTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5wFYQjKg_sendMessage(_c, 0, m);
  cMsg_HBX8Jlgp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_4bKTdrgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wwIlexPY_sendMessage(_c, 0, m);
  cMsg_3udlhUZt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_ZgNOC9Kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1U5Kwt8l_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_uvfrlPUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yUE2BQS1, 0, m, &cVar_yUE2BQS1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2mqeikrF, 0, m, &cVar_2mqeikrF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A4FpJGZX, 0, m, &cVar_A4FpJGZX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ssf5KvsB, 0, m, &cVar_Ssf5KvsB_sendMessage);
  cMsg_hxc7ZP9x_sendMessage(_c, 0, m);
  cMsg_7bgNDMzE_sendMessage(_c, 0, m);
  cMsg_vZlx34UW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_f5vNNmAN, 0, m, &cVar_f5vNNmAN_sendMessage);
  cMsg_MivokDJi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_xlr09doe, 0, m, &cVar_xlr09doe_sendMessage);
  cMsg_792o1F37_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_MsySs15b, 0, m, &cVar_MsySs15b_sendMessage);
  cMsg_XS7FElGh_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_eHIi3Mdz, 0, m, &cVar_eHIi3Mdz_sendMessage);
  cMsg_5imm2WWg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YNDWupEV, 0, m, &cVar_YNDWupEV_sendMessage);
  cMsg_eZVg5U2R_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wgD0ulil, 0, m, &cVar_wgD0ulil_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IrFu2BV1, 0, m, &cVar_IrFu2BV1_sendMessage);
  cMsg_IerXNTXa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_gRfDujDc, 0, m, &cVar_gRfDujDc_sendMessage);
  cMsg_0kuVbo01_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_3oesDe33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_PTrVRoVK_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_xhLcxRyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_I5yZpeK0, 0, m, &cVar_I5yZpeK0_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_muzsMn5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JAJgGrsQ, 0, m, &cVar_JAJgGrsQ_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_ccmRaM6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Vi8P4x4Z_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_psAEyiSR, VOf(Bf0));
    __hv_line_f(&sLine_SY2ByVhZ, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_C8LlioRL, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_ThCfEp2S, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_ev8nsZmV, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_d5QMGbx1, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_P5vxBnxb, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_NqIexGlN, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_mX4XOBoG, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_PqLQTKF0, VOf(Bf0));
    __hv_line_f(&sLine_p4Mwwn1a, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_lc2pWtRZ, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_PEl0cM2j, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_jXjgYgtO, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_abEOTDIT, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_QQr15uAR, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_1b2z7fxW, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Vrj2IzPC, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_RFyf6PBp, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_rjWL8mkl, VIf(Bf0));
    __hv_varread_f(&sVarf_upAXo88O, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_TZalSJHo, VIf(Bf0));
    __hv_varread_f(&sVarf_7uakEZQQ, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_tBc71MxI, VOf(Bf1));
    __hv_rpole_f(&sRPole_5iTIs5aN, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_NMBHp1Ay, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_0rPcyns3, VOf(Bf1));
    __hv_rpole_f(&sRPole_3ySRZJZP, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_XQgOHDd9, VOf(Bf0));
    __hv_rpole_f(&sRPole_EchHXCMh, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_sGQ1bkj5, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Kl7m588x, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_wudy6ehS, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_bnczco2C, VOf(Bf0));
    __hv_varread_f(&sVarf_kC3UN6mQ, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_kBPg30wm, VOf(Bf4));
    __hv_rpole_f(&sRPole_awfIb1zX, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Aj6f2uu2, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_CgILEHAU, VOf(Bf4));
    __hv_rpole_f(&sRPole_OMZ0gO8p, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_GJgZ3Jy7, VOf(Bf6));
    __hv_rpole_f(&sRPole_5u2Uo14U, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_SQFsElvz, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_5FFGs6CN, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Dn9wgpn5, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_PzBLxsC6, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_RFyf6PBp, VIf(Bf6));
    __hv_line_f(&sLine_71hDwW7i, VOf(Bf6));
    __hv_line_f(&sLine_CLErjpPs, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_upAXo88O, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
