/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvSignalLine.h"
#include "HvSignalDel1.h"
#include "HvControlVar.h"
#include "HvControlSystem.h"
#include "HvSignalTabread.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvControlDelay.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvControlSlice.h"
#include "HvSignalRPole.h"
#include "HvTable.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_ifWQ9olc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7dNWO8EP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OZomoQR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gnfJXszD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Hnj8qHFV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zI3v7Ej8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yUE2BQS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EpkWNJUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_knQbggNV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_WPvaqlCR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2mqeikrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DuhAe9M5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_azLd3mrQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_ImCUJfE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_A4FpJGZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ycNxTpse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1U5Kwt8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YqjG78PL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jM34Z6ni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nbwj9iXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_78coT0Y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tp3Dhuji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kesiMKnH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2hpWJdgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dBEpGtas_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_peRHsaGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yd571GCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jmq8gNQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1ZfCg0Ek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PTrVRoVK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QgdI9dut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ji91ao5W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IKv9m3kY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z1WQYvWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xCt4tES8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wpWXJASq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2vV7LQRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XAWCy5of_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aKfIke8b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B4gV7Djw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6eUGuIGi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_FJ4tca18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ssf5KvsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_M3wYou7u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hxc7ZP9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yqXe7Ik3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3JDWWHXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mYumhn8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4NhC9bUX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Gs3DW0Ey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_6Y4X3WlS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9XRNEqot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_baYrBAp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d3wWXw9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_84D3kKMv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NcK1OQcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MuRta2LB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7bgNDMzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jJ8ys1HB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AQQqtAoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_unWvSH5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZNBzjf5j_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_E0LDkeDI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_bLJS4gZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zpKyuUoF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XOkNDCnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kd97iut1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qi2UCjU8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wkrGDCeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HfVDdgjv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f5vNNmAN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vZlx34UW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YCuFYauI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dww7JcDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_011pNfA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PTz2LMiJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ywd223lA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_exzf3rN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TwXnoscz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xlr09doe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MivokDJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_21F8i8ce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZsK1QIQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GwRFTDJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LK3BJdQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OWie78zk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rEdj0hCB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_asuq8EkV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5FtY3y3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b344YQJ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MsySs15b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_792o1F37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NHoAa2xF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7rJpmfJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S5IZqM61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GnQnvfBh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nHcPxzpd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v950Rkue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z7Usf6Yk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCAjO3dN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWJ16iTK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IerXNTXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cw1QqdQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IrFu2BV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_42DounHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r33keX9y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6efK2HR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5BE8LNGl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0kuVbo01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Q4myVKmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gRfDujDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2f3KxNna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eHWL9HgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_plssL6Oa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_co8Snsms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eHIi3Mdz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XS7FElGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZF3IgOJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K7gZXQOx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zWjk2UjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6aGDNHDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vu46EY4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lGu8RheP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_51ddlN1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YNDWupEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5imm2WWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5w899kOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6B9sjaqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MBVGWuBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gGlpLr3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QcKitsxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5gisrWKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VgKkZAay_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bLR4ItGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZLNGWry1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wgD0ulil_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eZVg5U2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dz40T9vh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jk8Hhppn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RfEVqct9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRPBDwxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FHqBbHIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WJJokqBK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bHHy1THq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vW8QQu6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sWFdZFAz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6guIdFNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_13Z1jQ5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f4fhYsqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GIcYNYpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iHA4jcOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RetYYVmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5cyaypAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nQlNUy7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5wFYQjKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HBX8Jlgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wwIlexPY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3udlhUZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_I5yZpeK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nYsCo5G4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9wWGO2dI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gvekM5xi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YrZ4tAZC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wvl2CAg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yk3Q6Tt6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hOaSN32j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gImlrHMa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_4poTlJ59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_n6IUYVV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nn5IH9ff_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jf1F7X5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fJlR7m3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3GALuFgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s76YUkzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2hQTFAo4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IacaxXz1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JAJgGrsQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Vi8P4x4Z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_HRMK26b9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ALvlse0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_03wsokcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XNBgK53p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1fTaNBVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xa4lZM6f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Lm3IoON_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LZwgtu5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zKMxAiWA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GxXu7JBY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vCnhnTbm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gHw3oslj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RQuC3MKH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ckewGtO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6fd15RkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qWp5lXuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QhskTTes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_svgkNUzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1YQPu7Gq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8igfV476_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oaTy7tu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JWpLoa03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TIoZNzNf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3OUaSYxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8zKHFJJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EuFIVo7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5zEuDjku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZIbESW6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UVvqre6K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FZU7rWie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FbP6lcEf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lQtfQPpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1Vqio2Pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eEjsE6uM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FizgDTsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TRDuF8hZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_95zhQVZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WDN0vWCe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4u3fXgBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GDLZaHe2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NfnYLDdq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T0PKkI9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wnZl5LZn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BAB00Yg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c5dzVnWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pX71oNLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Wy0cO46O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r1ICWVDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mX0J9hDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fhpnkoLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_p6TfFmTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4bKTdrgj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZgNOC9Kf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uvfrlPUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3oesDe33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xhLcxRyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_muzsMn5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ccmRaM6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_psAEyiSR;
  SignalLine sLine_SY2ByVhZ;
  SignalTabhead sTabhead_C8LlioRL;
  SignalTabread sTabread_P5vxBnxb;
  SignalTabread sTabread_NqIexGlN;
  SignalLine sLine_mX4XOBoG;
  SignalLine sLine_PqLQTKF0;
  SignalLine sLine_p4Mwwn1a;
  SignalTabhead sTabhead_lc2pWtRZ;
  SignalTabread sTabread_QQr15uAR;
  SignalTabread sTabread_1b2z7fxW;
  SignalLine sLine_Vrj2IzPC;
  SignalTabwrite sTabwrite_rjWL8mkl;
  SignalTabwrite sTabwrite_TZalSJHo;
  SignalRPole sRPole_5iTIs5aN;
  SignalRPole sRPole_3ySRZJZP;
  SignalRPole sRPole_EchHXCMh;
  SignalDel1 sDel1_sGQ1bkj5;
  SignalLine sLine_wudy6ehS;
  SignalLine sLine_bnczco2C;
  SignalRPole sRPole_awfIb1zX;
  SignalRPole sRPole_OMZ0gO8p;
  SignalRPole sRPole_5u2Uo14U;
  SignalDel1 sDel1_SQFsElvz;
  SignalLine sLine_Dn9wgpn5;
  SignalLine sLine_PzBLxsC6;
  SignalLine sLine_71hDwW7i;
  SignalLine sLine_CLErjpPs;
  ControlVar cVar_ifWQ9olc;
  ControlVar cVar_7dNWO8EP;
  ControlVar cVar_OZomoQR4;
  ControlVar cVar_gnfJXszD;
  ControlSlice cSlice_zI3v7Ej8;
  ControlVar cVar_yUE2BQS1;
  ControlSlice cSlice_WPvaqlCR;
  ControlVar cVar_2mqeikrF;
  ControlSlice cSlice_ImCUJfE4;
  ControlVar cVar_A4FpJGZX;
  ControlBinop cBinop_1U5Kwt8l;
  ControlBinop cBinop_YqjG78PL;
  ControlBinop cBinop_78coT0Y6;
  ControlBinop cBinop_Tp3Dhuji;
  ControlBinop cBinop_dBEpGtas;
  ControlBinop cBinop_yd571GCd;
  ControlBinop cBinop_jmq8gNQK;
  ControlBinop cBinop_1ZfCg0Ek;
  ControlBinop cBinop_PTrVRoVK;
  ControlBinop cBinop_QgdI9dut;
  ControlBinop cBinop_Ji91ao5W;
  ControlBinop cBinop_IKv9m3kY;
  ControlBinop cBinop_wpWXJASq;
  ControlBinop cBinop_XAWCy5of;
  ControlBinop cBinop_aKfIke8b;
  ControlBinop cBinop_B4gV7Djw;
  ControlSlice cSlice_FJ4tca18;
  ControlVar cVar_Ssf5KvsB;
  ControlDelay cDelay_3JDWWHXH;
  ControlDelay cDelay_mYumhn8v;
  ControlBinop cBinop_Gs3DW0Ey;
  HvTable hTable_6Y4X3WlS;
  ControlBinop cBinop_baYrBAp6;
  ControlDelay cDelay_AQQqtAoP;
  ControlDelay cDelay_unWvSH5z;
  ControlBinop cBinop_E0LDkeDI;
  HvTable hTable_bLJS4gZp;
  ControlBinop cBinop_XOkNDCnd;
  ControlVar cVar_f5vNNmAN;
  ControlBinop cBinop_Dww7JcDK;
  ControlBinop cBinop_011pNfA6;
  SignalVarf sVarf_tBc71MxI;
  ControlBinop cBinop_ywd223lA;
  ControlBinop cBinop_exzf3rN5;
  ControlBinop cBinop_TwXnoscz;
  SignalVarf sVarf_7uakEZQQ;
  ControlVar cVar_xlr09doe;
  ControlBinop cBinop_ZsK1QIQn;
  ControlBinop cBinop_GwRFTDJ5;
  SignalVarf sVarf_0rPcyns3;
  ControlBinop cBinop_OWie78zk;
  ControlBinop cBinop_rEdj0hCB;
  ControlBinop cBinop_asuq8EkV;
  SignalVarf sVarf_NMBHp1Ay;
  ControlBinop cBinop_5FtY3y3v;
  ControlBinop cBinop_b344YQJ4;
  SignalVarf sVarf_XQgOHDd9;
  ControlVar cVar_MsySs15b;
  ControlBinop cBinop_7rJpmfJT;
  ControlBinop cBinop_S5IZqM61;
  ControlBinop cBinop_nHcPxzpd;
  ControlBinop cBinop_v950Rkue;
  ControlBinop cBinop_z7Usf6Yk;
  ControlBinop cBinop_wCAjO3dN;
  ControlBinop cBinop_sWJ16iTK;
  SignalVarf sVarf_Kl7m588x;
  ControlVar cVar_IrFu2BV1;
  ControlBinop cBinop_r33keX9y;
  ControlBinop cBinop_5BE8LNGl;
  SignalVarf sVarf_d5QMGbx1;
  SignalVarf sVarf_ThCfEp2S;
  SignalVarf sVarf_ev8nsZmV;
  ControlVar cVar_gRfDujDc;
  ControlBinop cBinop_eHWL9HgR;
  ControlBinop cBinop_co8Snsms;
  SignalVarf sVarf_abEOTDIT;
  SignalVarf sVarf_PEl0cM2j;
  SignalVarf sVarf_jXjgYgtO;
  ControlVar cVar_eHIi3Mdz;
  ControlBinop cBinop_K7gZXQOx;
  ControlBinop cBinop_zWjk2UjW;
  SignalVarf sVarf_kBPg30wm;
  ControlBinop cBinop_vu46EY4M;
  ControlBinop cBinop_lGu8RheP;
  ControlBinop cBinop_51ddlN1K;
  SignalVarf sVarf_kC3UN6mQ;
  ControlVar cVar_YNDWupEV;
  ControlBinop cBinop_6B9sjaqx;
  ControlBinop cBinop_MBVGWuBn;
  SignalVarf sVarf_CgILEHAU;
  ControlBinop cBinop_QcKitsxz;
  ControlBinop cBinop_5gisrWKS;
  ControlBinop cBinop_VgKkZAay;
  SignalVarf sVarf_Aj6f2uu2;
  ControlBinop cBinop_bLR4ItGb;
  ControlBinop cBinop_ZLNGWry1;
  SignalVarf sVarf_GJgZ3Jy7;
  ControlVar cVar_wgD0ulil;
  ControlBinop cBinop_Jk8Hhppn;
  ControlBinop cBinop_RfEVqct9;
  ControlBinop cBinop_FHqBbHIk;
  ControlBinop cBinop_WJJokqBK;
  ControlBinop cBinop_bHHy1THq;
  ControlBinop cBinop_vW8QQu6Z;
  ControlBinop cBinop_sWFdZFAz;
  SignalVarf sVarf_5FFGs6CN;
  SignalVarf sVarf_RFyf6PBp;
  SignalVarf sVarf_upAXo88O;
  ControlVar cVar_I5yZpeK0;
  ControlBinop cBinop_nYsCo5G4;
  ControlIf cIf_9wWGO2dI;
  ControlIf cIf_gvekM5xi;
  ControlVar cVar_YrZ4tAZC;
  ControlVar cVar_wvl2CAg6;
  ControlVar cVar_yk3Q6Tt6;
  ControlVar cVar_hOaSN32j;
  ControlSlice cSlice_4poTlJ59;
  ControlSlice cSlice_n6IUYVV2;
  ControlVar cVar_nn5IH9ff;
  ControlIf cIf_jf1F7X5r;
  ControlBinop cBinop_s76YUkzC;
  ControlVar cVar_JAJgGrsQ;
  ControlBinop cBinop_ckewGtO9;
  ControlBinop cBinop_6fd15RkK;
  ControlBinop cBinop_FizgDTsM;
  ControlBinop cBinop_TRDuF8hZ;
  ControlBinop cBinop_95zhQVZG;
  ControlBinop cBinop_GDLZaHe2;
  ControlBinop cBinop_NfnYLDdq;
  ControlBinop cBinop_T0PKkI9x;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
